@@ -1,7 +1,6 @@
 if(dev.cur() <= 1) get(getOption("device"))()
 
-oldpar <- par(ask = interactive() &&
-            (.Device %in% c("X11", "GTK", "windows", "Macintosh")))
+oldpar <- par(ask = interactive() && dev.interactive(orNone=TRUE))
 oldoptions <- options(warn=-1)
 
 fanfare <- function(stuff) {
